Roadmap
=======


Inept is still in its early development.

Here is a non-exhaustive list of the upcoming features:

 - handling complexe types like file/path or enum
 - composing tree declarations
 - extracting sub configurations
 - serialization to/from different configuration file formats (yaml, json, INI, ...)
 - improving the command line interface
